@@ -192,6 +192,10 @@ if(file.exists("plfit_res.rds")) {
 ## ----results='hide', eval=FALSE------------------------------------------
 #  estimate_xmin(m_m, pars=seq(1.5, 2.5, 0.01))
 
+## ----cache=TRUE----------------------------------------------------------
+x = rpldis(1000, 1, 2)
+plfit(x)
+
 ## ----the_ctn_case--------------------------------------------------------
 r = rplcon(1000, 10, 2.5)
 
